@@ -109,8 +109,8 @@ void MainWindow::editCategories()
     QString cmd = QString("/usr/bin/osso-xterm -e \"vi %1\"").arg(cf);
     QProcess* p = new QProcess(this);
     p->start(cmd);
-    // osso-xterm will exit after launch
     p->waitForFinished();
+    delete p;
 
 }
 
