@@ -27,6 +27,8 @@ private slots:
 
     void populate();
     void changeCategory();
+    void editCategories();
+    void editCatogiesDone();
 
 protected:
     void changeEvent(QEvent *e);
