@@ -11,7 +11,7 @@ void PlatUtil::configureWindow(QWidget *wdg)
 {
 #ifdef Q_WS_MAEMO_5
     wdg->setAttribute(Qt::WA_Maemo5StackedWindow);
-    wdg->setAttribute(Qt::WA_Maemo5AutoOrientation);
+    //wdg->setAttribute(Qt::WA_Maemo5AutoOrientation);
 #endif
 }
 
