@@ -197,6 +197,13 @@ QStringList RedditSession::getCategories()
         if (line.length())
             cats.append(line);
 
+    }
+    f.close();
+    // "easy" way to reset - just delete all lines
+    if (cats.empty()) {
+        f.remove();
+        cats = getCategories();
+
     }
 
     return cats;
